pub enum WlanPhyNotifyRequest {
OnCriticalError {
payload: WlanPhyNotifyOnCriticalErrorRequest,
responder: WlanPhyNotifyOnCriticalErrorResponder,
},
OnCountryCodeChange {
payload: WlanPhyNotifyOnCountryCodeChangeRequest,
responder: WlanPhyNotifyOnCountryCodeChangeResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: WlanPhyNotifyControlHandle,
method_type: MethodType,
},
}Expand description
This protocol is specifically meant for passing events/notifications from the WlanPhy server to its client.
Variants
OnCriticalError
Indicate to the receiver that the PHY has encountered a critical error specifying a reason code.
Fields

payload: WlanPhyNotifyOnCriticalErrorRequest
responder: WlanPhyNotifyOnCriticalErrorResponderOnCountryCodeChange
Indicate to the receiver that the firmware running on wlan hardware has detected a change in country code.
Fields

responder: WlanPhyNotifyOnCountryCodeChangeResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: WlanPhyNotifyControlHandle
method_type: MethodTypeImplementations
Sourceimpl WlanPhyNotifyRequest
impl WlanPhyNotifyRequest
pub fn into_on_critical_error( self, ) -> Option<(WlanPhyNotifyOnCriticalErrorRequest, WlanPhyNotifyOnCriticalErrorResponder)>
pub fn into_on_country_code_change( self, ) -> Option<(WlanPhyNotifyOnCountryCodeChangeRequest, WlanPhyNotifyOnCountryCodeChangeResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL