WlanPhyRequest

Enum WlanPhyRequest 

pub enum WlanPhyRequest {
Show 18 variants Init { payload: WlanPhyInitRequest, responder: WlanPhyInitResponder, }, GetSupportedMacRoles { responder: WlanPhyGetSupportedMacRolesResponder, }, CreateIface { payload: WlanPhyCreateIfaceRequest, responder: WlanPhyCreateIfaceResponder, }, DestroyIface { payload: WlanPhyDestroyIfaceRequest, responder: WlanPhyDestroyIfaceResponder, }, SetCountry { country: [u8; 2], responder: WlanPhySetCountryResponder, }, ClearCountry { responder: WlanPhyClearCountryResponder, }, GetCountry { responder: WlanPhyGetCountryResponder, }, SetPowerSaveMode { payload: WlanPhySetPowerSaveModeRequest, responder: WlanPhySetPowerSaveModeResponder, }, GetPowerSaveMode { responder: WlanPhyGetPowerSaveModeResponder, }, PowerDown { responder: WlanPhyPowerDownResponder, }, PowerUp { responder: WlanPhyPowerUpResponder, }, Reset { responder: WlanPhyResetResponder, }, GetPowerState { responder: WlanPhyGetPowerStateResponder, }, SetBtCoexistenceMode { payload: WlanPhySetBtCoexistenceModeRequest, responder: WlanPhySetBtCoexistenceModeResponder, }, SetTxPowerScenario { payload: WlanPhySetTxPowerScenarioRequest, responder: WlanPhySetTxPowerScenarioResponder, }, ResetTxPowerScenario { responder: WlanPhyResetTxPowerScenarioResponder, }, GetTxPowerScenario { responder: WlanPhyGetTxPowerScenarioResponder, },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: WlanPhyControlHandle, method_type: MethodType, },
}

Variants



Init

This method can be used by the WlanPhy client to send the client end of the WlanPhyNotify endpoint for the WlanPhy server to use. If the WlanPhy client never invokes this method that is an indirect implication that the WlanPhyNotify is not supported. Some possible error codes are: ZX_ERR_NOT_SUPPORTED: The WlanPhy server does not support the WlanPhyNotify protocol.



GetSupportedMacRoles

MAC roles supported for ifaces on the physical device.



CreateIface

Create a new interface with the specified role, returning the interface id.
Some common error codes are:
ZX_ERR_NO_RESOURCES: maximum number of interfaces have already been created.
ZX_ERR_NOT_SUPPORTED: device does not support the specified role.



DestroyIface

Destroy the interface with the matching id.
Some common error codes are:
ZX_ERR_NOT_FOUND: Specified iface does not exist or has already been removed.
ZX_ERR_SHOULD_WAIT: Device is busy and cannot be removed, try again later.



SetCountry

Set country with a 2-byte country code.
Some common error codes are:
ZX_ERR_NOT_FOUND: Specified country code not supported. PHY state is left unchanged.

Fields

country: [u8; 2]


ClearCountry

Set device to a world-safe country, i.e. a mode that conforms to all regulatory constraints globally.
Generally expected to succeed if the device is in a functional state.



GetCountry

Read currently configured country. Implementations are advised to read the country directly from the firmware, where possible.
Generally expected to succeed if the device is in a functional state.



SetPowerSaveMode

Set Power Save mode on device. In most implementations this likely to be set in Firmware.
Some common error codes are:
ZX_ERR_NOT_SUPPORTED: Specified Power Save mode not supported.



GetPowerSaveMode

Get current Power Save mode from device. In most implementation this likely to be retrieved from Firmware.



PowerDown

Power up/down/reset the wlan chip. If supported, PowerDown will power down the wlan chip if it is currently powered on. Any existing interfaces should have already been deleted before making this call or else the driver will fail the call with error code ZX_ERR_INTERNAL. Other possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered down.



PowerUp

If supported, PowerUp will power up the wlan chip if it is currently powered down. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered up.

Fields



Reset

If supported, Reset functionality implements PowerDown then PowerUp in an attempt to recover from an error state. For example, if an interface gets into a bad state or if firmware crashes, the firmware/chip may be unable to perform some actions and Reset may be able to clear the bad state. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered down.

Fields



GetPowerState

Returns the current power state of the wlan chip. After successful initialization of the wlan driver, the state is set to true (power on) by default. power_on set to true indicates that the wlan chip is powered on and false indicates the wlan chip is powered off.



SetBtCoexistenceMode

Set the Bluetooth coexistence mode. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: device does not support the specified BT coexistence mode.



SetTxPowerScenario



ResetTxPowerScenario



GetTxPowerScenario



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

control_handle: WlanPhyControlHandle
method_type: MethodType

Implementations

Source

impl WlanPhyRequest

pub fn into_init(self) -> Option<(WlanPhyInitRequest, WlanPhyInitResponder)>

pub fn into_get_supported_mac_roles( self, ) -> Option<WlanPhyGetSupportedMacRolesResponder>

pub fn into_create_iface( self, ) -> Option<(WlanPhyCreateIfaceRequest, WlanPhyCreateIfaceResponder)>

pub fn into_destroy_iface( self, ) -> Option<(WlanPhyDestroyIfaceRequest, WlanPhyDestroyIfaceResponder)>

pub fn into_set_country(self) -> Option<([u8; 2], WlanPhySetCountryResponder)>

pub fn into_clear_country(self) -> Option<WlanPhyClearCountryResponder>

pub fn into_get_country(self) -> Option<WlanPhyGetCountryResponder>

pub fn into_set_power_save_mode( self, ) -> Option<(WlanPhySetPowerSaveModeRequest, WlanPhySetPowerSaveModeResponder)>

pub fn into_get_power_save_mode( self, ) -> Option<WlanPhyGetPowerSaveModeResponder>

pub fn into_power_down(self) -> Option<WlanPhyPowerDownResponder>

pub fn into_power_up(self) -> Option<WlanPhyPowerUpResponder>

pub fn into_reset(self) -> Option<WlanPhyResetResponder>

pub fn into_get_power_state(self) -> Option<WlanPhyGetPowerStateResponder>

pub fn into_set_bt_coexistence_mode( self, ) -> Option<(WlanPhySetBtCoexistenceModeRequest, WlanPhySetBtCoexistenceModeResponder)>

pub fn into_set_tx_power_scenario( self, ) -> Option<(WlanPhySetTxPowerScenarioRequest, WlanPhySetTxPowerScenarioResponder)>

pub fn into_reset_tx_power_scenario( self, ) -> Option<WlanPhyResetTxPowerScenarioResponder>

pub fn into_get_tx_power_scenario( self, ) -> Option<WlanPhyGetTxPowerScenarioResponder>

pub fn method_name(&self) -> &'static str

Name of the method defined in FIDL