WlanPhyCreateIfaceRequest

Struct WlanPhyCreateIfaceRequest 

pub struct WlanPhyCreateIfaceRequest {
    pub role: Option<WlanMacRole>,
    pub mlme_channel: Option<Channel>,
    pub init_sta_addr: Option<[u8; 6]>,
    /* private fields */
}

Fields

role: Option<WlanMacRole>

The station role for this interface. A device may support multiple roles, but an interface is instantiated with a single role. This field is required.

mlme_channel: Option<Channel>

A handle to the direct MLME channel, if supported by the driver. This channel should be used by SME to communicate with MLME via the MLME protocol. This field is required.

init_sta_addr: Option<[u8; 6]>

The initial station address set from configuration layer.

Excluding this field or providing a MAC address with all zeroes will result in the driver assigning a MAC address that may or may not be randomized.