pub struct WlanPhyInitRequest {
pub notify_client: Option<ClientEnd<WlanPhyNotifyMarker>>,
/* private fields */
}Fields
notify_client: Option<ClientEnd<WlanPhyNotifyMarker>>Client end of a channel that notifies the WlanPhy client of events that occur on the server, e.g., a critical error with the PHY itself.
This field is required.