pub struct WlanPhyInitResponse {
pub power_dependency_token: Option<Event>,
/* private fields */
}Fields
power_dependency_token: Option<Event>If power control is supported by the driver and hardware, a dependency token will be returned to allow the upper layers to express a dependency on specified power states (e.g. “on”).