pub struct WlanPhyMarker;Trait Implementations
Sourceimpl Clone for WlanPhyMarker
impl Clone for WlanPhyMarker
Sourcefn clone(&self) -> WlanPhyMarker
fn clone(&self) -> WlanPhyMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhyMarker
Sourceimpl Debug for WlanPhyMarker
impl Debug for WlanPhyMarker
Sourceimpl DiscoverableProtocolMarker for WlanPhyMarker
impl DiscoverableProtocolMarker for WlanPhyMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for WlanPhyMarker
Sourceimpl Hash for WlanPhyMarker
impl Hash for WlanPhyMarker
Sourceimpl Ord for WlanPhyMarker
impl Ord for WlanPhyMarker
Sourcefn cmp(&self, other: &WlanPhyMarker) -> Ordering
fn cmp(&self, other: &WlanPhyMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhyMarker
impl PartialEq for WlanPhyMarker
Sourcefn eq(&self, other: &WlanPhyMarker) -> bool
fn eq(&self, other: &WlanPhyMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhyMarker
impl PartialOrd for WlanPhyMarker
Sourceimpl ProtocolMarker for WlanPhyMarker
impl ProtocolMarker for WlanPhyMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.wlan.phy.WlanPhy"
const DEBUG_NAME: &'static str = "fuchsia.wlan.phy.WlanPhy"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = WlanPhyProxy
type Proxy = WlanPhyProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = WlanPhyRequestStream
type RequestStream = WlanPhyRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = WlanPhySynchronousProxy
type SynchronousProxy = WlanPhySynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for WlanPhyMarker