pub struct WlanPhyNotifyMarker;Trait Implementations
Sourceimpl Clone for WlanPhyNotifyMarker
impl Clone for WlanPhyNotifyMarker
Sourcefn clone(&self) -> WlanPhyNotifyMarker
fn clone(&self) -> WlanPhyNotifyMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhyNotifyMarker
Sourceimpl Debug for WlanPhyNotifyMarker
impl Debug for WlanPhyNotifyMarker
Sourceimpl DiscoverableProtocolMarker for WlanPhyNotifyMarker
impl DiscoverableProtocolMarker for WlanPhyNotifyMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for WlanPhyNotifyMarker
Sourceimpl Hash for WlanPhyNotifyMarker
impl Hash for WlanPhyNotifyMarker
Sourceimpl Ord for WlanPhyNotifyMarker
impl Ord for WlanPhyNotifyMarker
Sourcefn cmp(&self, other: &WlanPhyNotifyMarker) -> Ordering
fn cmp(&self, other: &WlanPhyNotifyMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhyNotifyMarker
impl PartialEq for WlanPhyNotifyMarker
Sourcefn eq(&self, other: &WlanPhyNotifyMarker) -> bool
fn eq(&self, other: &WlanPhyNotifyMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhyNotifyMarker
impl PartialOrd for WlanPhyNotifyMarker
Sourceimpl ProtocolMarker for WlanPhyNotifyMarker
impl ProtocolMarker for WlanPhyNotifyMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.wlan.phy.WlanPhyNotify"
const DEBUG_NAME: &'static str = "fuchsia.wlan.phy.WlanPhyNotify"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = WlanPhyNotifyProxy
type Proxy = WlanPhyNotifyProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = WlanPhyNotifyRequestStream
type RequestStream = WlanPhyNotifyRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = WlanPhyNotifySynchronousProxy
type SynchronousProxy = WlanPhyNotifySynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for WlanPhyNotifyMarker