pub struct WlanPhyNotifyOnCountryCodeChangeRequest {
pub phy_country: Option<[u8; 2]>,
/* private fields */
}Fields
phy_country: Option<[u8; 2]>Trait Implementations
Sourceimpl Clone for WlanPhyNotifyOnCountryCodeChangeRequest
impl Clone for WlanPhyNotifyOnCountryCodeChangeRequest
Sourcefn clone(&self) -> WlanPhyNotifyOnCountryCodeChangeRequest
fn clone(&self) -> WlanPhyNotifyOnCountryCodeChangeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<WlanPhyNotifyOnCountryCodeChangeRequest, D> for WlanPhyNotifyOnCountryCodeChangeRequestwhere
D: ResourceDialect,
impl<D> Decode<WlanPhyNotifyOnCountryCodeChangeRequest, D> for WlanPhyNotifyOnCountryCodeChangeRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> WlanPhyNotifyOnCountryCodeChangeRequest
fn new_empty() -> WlanPhyNotifyOnCountryCodeChangeRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for WlanPhyNotifyOnCountryCodeChangeRequest
impl Default for WlanPhyNotifyOnCountryCodeChangeRequest
Sourcefn default() -> WlanPhyNotifyOnCountryCodeChangeRequest
fn default() -> WlanPhyNotifyOnCountryCodeChangeRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<WlanPhyNotifyOnCountryCodeChangeRequest, D> for &WlanPhyNotifyOnCountryCodeChangeRequestwhere
D: ResourceDialect,
impl<D> Encode<WlanPhyNotifyOnCountryCodeChangeRequest, D> for &WlanPhyNotifyOnCountryCodeChangeRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for WlanPhyNotifyOnCountryCodeChangeRequest
impl PartialEq for WlanPhyNotifyOnCountryCodeChangeRequest
Sourcefn eq(&self, other: &WlanPhyNotifyOnCountryCodeChangeRequest) -> bool
fn eq(&self, other: &WlanPhyNotifyOnCountryCodeChangeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for WlanPhyNotifyOnCountryCodeChangeRequest
impl StructuralPartialEq for WlanPhyNotifyOnCountryCodeChangeRequest
Sourceimpl TypeMarker for WlanPhyNotifyOnCountryCodeChangeRequest
impl TypeMarker for WlanPhyNotifyOnCountryCodeChangeRequest
Sourcetype Owned = WlanPhyNotifyOnCountryCodeChangeRequest
type Owned = WlanPhyNotifyOnCountryCodeChangeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhyNotifyOnCountryCodeChangeRequest
impl ValueTypeMarker for WlanPhyNotifyOnCountryCodeChangeRequest
Sourcetype Borrowed<'a> = &'a WlanPhyNotifyOnCountryCodeChangeRequest
type Borrowed<'a> = &'a WlanPhyNotifyOnCountryCodeChangeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<WlanPhyNotifyOnCountryCodeChangeRequest as TypeMarker>::Owned,
) -> <WlanPhyNotifyOnCountryCodeChangeRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<WlanPhyNotifyOnCountryCodeChangeRequest as TypeMarker>::Owned, ) -> <WlanPhyNotifyOnCountryCodeChangeRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for WlanPhyNotifyOnCountryCodeChangeRequest
impl RefUnwindSafe for WlanPhyNotifyOnCountryCodeChangeRequest
impl Send for WlanPhyNotifyOnCountryCodeChangeRequest
impl Sync for WlanPhyNotifyOnCountryCodeChangeRequest
impl Unpin for WlanPhyNotifyOnCountryCodeChangeRequest
impl UnsafeUnpin for WlanPhyNotifyOnCountryCodeChangeRequest
impl UnwindSafe for WlanPhyNotifyOnCountryCodeChangeRequest