pub struct WlanPhyNotifyProxy { /* private fields */ }Implementations
Sourceimpl WlanPhyNotifyProxy
impl WlanPhyNotifyProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.wlan.phy/WlanPhyNotify.
Sourcepub fn take_event_stream(&self) -> WlanPhyNotifyEventStream
pub fn take_event_stream(&self) -> WlanPhyNotifyEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn on_critical_error(
&self,
payload: &WlanPhyNotifyOnCriticalErrorRequest,
) -> QueryResponseFut<WlanPhyNotifyOnCriticalErrorResult, DefaultFuchsiaResourceDialect>
pub fn on_critical_error( &self, payload: &WlanPhyNotifyOnCriticalErrorRequest, ) -> QueryResponseFut<WlanPhyNotifyOnCriticalErrorResult, DefaultFuchsiaResourceDialect>
Indicate to the receiver that the PHY has encountered a critical error specifying a reason code.
Sourcepub fn on_country_code_change(
&self,
payload: &WlanPhyNotifyOnCountryCodeChangeRequest,
) -> QueryResponseFut<WlanPhyNotifyOnCountryCodeChangeResult, DefaultFuchsiaResourceDialect>
pub fn on_country_code_change( &self, payload: &WlanPhyNotifyOnCountryCodeChangeRequest, ) -> QueryResponseFut<WlanPhyNotifyOnCountryCodeChangeResult, DefaultFuchsiaResourceDialect>
Indicate to the receiver that the firmware running on wlan hardware has detected a change in country code.