pub struct WlanPhyNotifySynchronousProxy { /* private fields */ }Implementations
Sourceimpl WlanPhyNotifySynchronousProxy
impl WlanPhyNotifySynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<WlanPhyNotifyEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<WlanPhyNotifyEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn on_critical_error(
&self,
payload: &WlanPhyNotifyOnCriticalErrorRequest,
___deadline: MonotonicInstant,
) -> Result<WlanPhyNotifyOnCriticalErrorResult, Error>
pub fn on_critical_error( &self, payload: &WlanPhyNotifyOnCriticalErrorRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhyNotifyOnCriticalErrorResult, Error>
Indicate to the receiver that the PHY has encountered a critical error specifying a reason code.
Sourcepub fn on_country_code_change(
&self,
payload: &WlanPhyNotifyOnCountryCodeChangeRequest,
___deadline: MonotonicInstant,
) -> Result<WlanPhyNotifyOnCountryCodeChangeResult, Error>
pub fn on_country_code_change( &self, payload: &WlanPhyNotifyOnCountryCodeChangeRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhyNotifyOnCountryCodeChangeResult, Error>
Indicate to the receiver that the firmware running on wlan hardware has detected a change in country code.