pub struct WlanPhySetBtCoexistenceModeRequest {
pub mode: Option<BtCoexistenceMode>,
/* private fields */
}Fields
mode: Option<BtCoexistenceMode>Trait Implementations
Sourceimpl Clone for WlanPhySetBtCoexistenceModeRequest
impl Clone for WlanPhySetBtCoexistenceModeRequest
Sourcefn clone(&self) -> WlanPhySetBtCoexistenceModeRequest
fn clone(&self) -> WlanPhySetBtCoexistenceModeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<WlanPhySetBtCoexistenceModeRequest, D> for WlanPhySetBtCoexistenceModeRequestwhere
D: ResourceDialect,
impl<D> Decode<WlanPhySetBtCoexistenceModeRequest, D> for WlanPhySetBtCoexistenceModeRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> WlanPhySetBtCoexistenceModeRequest
fn new_empty() -> WlanPhySetBtCoexistenceModeRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for WlanPhySetBtCoexistenceModeRequest
impl Default for WlanPhySetBtCoexistenceModeRequest
Sourcefn default() -> WlanPhySetBtCoexistenceModeRequest
fn default() -> WlanPhySetBtCoexistenceModeRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<WlanPhySetBtCoexistenceModeRequest, D> for &WlanPhySetBtCoexistenceModeRequestwhere
D: ResourceDialect,
impl<D> Encode<WlanPhySetBtCoexistenceModeRequest, D> for &WlanPhySetBtCoexistenceModeRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for WlanPhySetBtCoexistenceModeRequest
impl PartialEq for WlanPhySetBtCoexistenceModeRequest
Sourcefn eq(&self, other: &WlanPhySetBtCoexistenceModeRequest) -> bool
fn eq(&self, other: &WlanPhySetBtCoexistenceModeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for WlanPhySetBtCoexistenceModeRequest
impl StructuralPartialEq for WlanPhySetBtCoexistenceModeRequest
Sourceimpl TypeMarker for WlanPhySetBtCoexistenceModeRequest
impl TypeMarker for WlanPhySetBtCoexistenceModeRequest
Sourcetype Owned = WlanPhySetBtCoexistenceModeRequest
type Owned = WlanPhySetBtCoexistenceModeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhySetBtCoexistenceModeRequest
impl ValueTypeMarker for WlanPhySetBtCoexistenceModeRequest
Sourcetype Borrowed<'a> = &'a WlanPhySetBtCoexistenceModeRequest
type Borrowed<'a> = &'a WlanPhySetBtCoexistenceModeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<WlanPhySetBtCoexistenceModeRequest as TypeMarker>::Owned,
) -> <WlanPhySetBtCoexistenceModeRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<WlanPhySetBtCoexistenceModeRequest as TypeMarker>::Owned, ) -> <WlanPhySetBtCoexistenceModeRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for WlanPhySetBtCoexistenceModeRequest
impl RefUnwindSafe for WlanPhySetBtCoexistenceModeRequest
impl Send for WlanPhySetBtCoexistenceModeRequest
impl Sync for WlanPhySetBtCoexistenceModeRequest
impl Unpin for WlanPhySetBtCoexistenceModeRequest
impl UnsafeUnpin for WlanPhySetBtCoexistenceModeRequest
impl UnwindSafe for WlanPhySetBtCoexistenceModeRequest