#[repr(C)]pub struct WlanPhySetCountryRequest {
pub country: [u8; 2],
}Fields
country: [u8; 2]Trait Implementations
Sourceimpl Clone for WlanPhySetCountryRequest
impl Clone for WlanPhySetCountryRequest
Sourcefn clone(&self) -> WlanPhySetCountryRequest
fn clone(&self) -> WlanPhySetCountryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhySetCountryRequest
Sourceimpl Debug for WlanPhySetCountryRequest
impl Debug for WlanPhySetCountryRequest
Sourceimpl<D> Decode<WlanPhySetCountryRequest, D> for WlanPhySetCountryRequestwhere
D: ResourceDialect,
impl<D> Decode<WlanPhySetCountryRequest, D> for WlanPhySetCountryRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> WlanPhySetCountryRequest
fn new_empty() -> WlanPhySetCountryRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<WlanPhySetCountryRequest, D> for &WlanPhySetCountryRequestwhere
D: ResourceDialect,
impl<D> Encode<WlanPhySetCountryRequest, D> for &WlanPhySetCountryRequestwhere
D: ResourceDialect,
impl Eq for WlanPhySetCountryRequest
Sourceimpl Hash for WlanPhySetCountryRequest
impl Hash for WlanPhySetCountryRequest
Sourceimpl Ord for WlanPhySetCountryRequest
impl Ord for WlanPhySetCountryRequest
Sourcefn cmp(&self, other: &WlanPhySetCountryRequest) -> Ordering
fn cmp(&self, other: &WlanPhySetCountryRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhySetCountryRequest
impl PartialEq for WlanPhySetCountryRequest
Sourcefn eq(&self, other: &WlanPhySetCountryRequest) -> bool
fn eq(&self, other: &WlanPhySetCountryRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhySetCountryRequest
impl PartialOrd for WlanPhySetCountryRequest
impl Persistable for WlanPhySetCountryRequest
impl StructuralPartialEq for WlanPhySetCountryRequest
Sourceimpl TypeMarker for WlanPhySetCountryRequest
impl TypeMarker for WlanPhySetCountryRequest
Sourcetype Owned = WlanPhySetCountryRequest
type Owned = WlanPhySetCountryRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhySetCountryRequest
impl ValueTypeMarker for WlanPhySetCountryRequest
Sourcetype Borrowed<'a> = &'a WlanPhySetCountryRequest
type Borrowed<'a> = &'a WlanPhySetCountryRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<WlanPhySetCountryRequest as TypeMarker>::Owned,
) -> <WlanPhySetCountryRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<WlanPhySetCountryRequest as TypeMarker>::Owned, ) -> <WlanPhySetCountryRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for WlanPhySetCountryRequest
impl RefUnwindSafe for WlanPhySetCountryRequest
impl Send for WlanPhySetCountryRequest
impl Sync for WlanPhySetCountryRequest
impl Unpin for WlanPhySetCountryRequest
impl UnsafeUnpin for WlanPhySetCountryRequest
impl UnwindSafe for WlanPhySetCountryRequest