pub struct WlanPhySetTxPowerScenarioRequest {
pub scenario: Option<TxPowerScenario>,
/* private fields */
}Fields
scenario: Option<TxPowerScenario>Trait Implementations
Sourceimpl Clone for WlanPhySetTxPowerScenarioRequest
impl Clone for WlanPhySetTxPowerScenarioRequest
Sourcefn clone(&self) -> WlanPhySetTxPowerScenarioRequest
fn clone(&self) -> WlanPhySetTxPowerScenarioRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<WlanPhySetTxPowerScenarioRequest, D> for WlanPhySetTxPowerScenarioRequestwhere
D: ResourceDialect,
impl<D> Decode<WlanPhySetTxPowerScenarioRequest, D> for WlanPhySetTxPowerScenarioRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> WlanPhySetTxPowerScenarioRequest
fn new_empty() -> WlanPhySetTxPowerScenarioRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for WlanPhySetTxPowerScenarioRequest
impl Default for WlanPhySetTxPowerScenarioRequest
Sourcefn default() -> WlanPhySetTxPowerScenarioRequest
fn default() -> WlanPhySetTxPowerScenarioRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<WlanPhySetTxPowerScenarioRequest, D> for &WlanPhySetTxPowerScenarioRequestwhere
D: ResourceDialect,
impl<D> Encode<WlanPhySetTxPowerScenarioRequest, D> for &WlanPhySetTxPowerScenarioRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for WlanPhySetTxPowerScenarioRequest
impl PartialEq for WlanPhySetTxPowerScenarioRequest
Sourcefn eq(&self, other: &WlanPhySetTxPowerScenarioRequest) -> bool
fn eq(&self, other: &WlanPhySetTxPowerScenarioRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for WlanPhySetTxPowerScenarioRequest
impl StructuralPartialEq for WlanPhySetTxPowerScenarioRequest
Sourceimpl TypeMarker for WlanPhySetTxPowerScenarioRequest
impl TypeMarker for WlanPhySetTxPowerScenarioRequest
Sourcetype Owned = WlanPhySetTxPowerScenarioRequest
type Owned = WlanPhySetTxPowerScenarioRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhySetTxPowerScenarioRequest
impl ValueTypeMarker for WlanPhySetTxPowerScenarioRequest
Sourcetype Borrowed<'a> = &'a WlanPhySetTxPowerScenarioRequest
type Borrowed<'a> = &'a WlanPhySetTxPowerScenarioRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<WlanPhySetTxPowerScenarioRequest as TypeMarker>::Owned,
) -> <WlanPhySetTxPowerScenarioRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<WlanPhySetTxPowerScenarioRequest as TypeMarker>::Owned, ) -> <WlanPhySetTxPowerScenarioRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for WlanPhySetTxPowerScenarioRequest
impl RefUnwindSafe for WlanPhySetTxPowerScenarioRequest
impl Send for WlanPhySetTxPowerScenarioRequest
impl Sync for WlanPhySetTxPowerScenarioRequest
impl Unpin for WlanPhySetTxPowerScenarioRequest
impl UnsafeUnpin for WlanPhySetTxPowerScenarioRequest
impl UnwindSafe for WlanPhySetTxPowerScenarioRequest