WlanPhySynchronousProxy

Struct WlanPhySynchronousProxy 

pub struct WlanPhySynchronousProxy { /* private fields */ }

Implementations

Source

impl WlanPhySynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<WlanPhyEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn init( &self, payload: WlanPhyInitRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhyInitResult, Error>

This method can be used by the WlanPhy client to send the client end of the WlanPhyNotify endpoint for the WlanPhy server to use. If the WlanPhy client never invokes this method that is an indirect implication that the WlanPhyNotify is not supported. Some possible error codes are: ZX_ERR_NOT_SUPPORTED: The WlanPhy server does not support the WlanPhyNotify protocol.

pub fn get_supported_mac_roles( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyGetSupportedMacRolesResult, Error>

MAC roles supported for ifaces on the physical device.

pub fn create_iface( &self, payload: WlanPhyCreateIfaceRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhyCreateIfaceResult, Error>

Create a new interface with the specified role, returning the interface id.
Some common error codes are:
ZX_ERR_NO_RESOURCES: maximum number of interfaces have already been created.
ZX_ERR_NOT_SUPPORTED: device does not support the specified role.

pub fn destroy_iface( &self, payload: &WlanPhyDestroyIfaceRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhyDestroyIfaceResult, Error>

Destroy the interface with the matching id.
Some common error codes are:
ZX_ERR_NOT_FOUND: Specified iface does not exist or has already been removed.
ZX_ERR_SHOULD_WAIT: Device is busy and cannot be removed, try again later.

pub fn set_country( &self, country: &[u8; 2], ___deadline: MonotonicInstant, ) -> Result<WlanPhySetCountryResult, Error>

Set country with a 2-byte country code.
Some common error codes are:
ZX_ERR_NOT_FOUND: Specified country code not supported. PHY state is left unchanged.

pub fn clear_country( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyClearCountryResult, Error>

Set device to a world-safe country, i.e. a mode that conforms to all regulatory constraints globally.
Generally expected to succeed if the device is in a functional state.

pub fn get_country( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyGetCountryResult, Error>

Read currently configured country. Implementations are advised to read the country directly from the firmware, where possible.
Generally expected to succeed if the device is in a functional state.

pub fn set_power_save_mode( &self, payload: &WlanPhySetPowerSaveModeRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhySetPowerSaveModeResult, Error>

Set Power Save mode on device. In most implementations this likely to be set in Firmware.
Some common error codes are:
ZX_ERR_NOT_SUPPORTED: Specified Power Save mode not supported.

pub fn get_power_save_mode( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyGetPowerSaveModeResult, Error>

Get current Power Save mode from device. In most implementation this likely to be retrieved from Firmware.

pub fn power_down( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyPowerDownResult, Error>

Power up/down/reset the wlan chip. If supported, PowerDown will power down the wlan chip if it is currently powered on. Any existing interfaces should have already been deleted before making this call or else the driver will fail the call with error code ZX_ERR_INTERNAL. Other possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered down.

pub fn power_up( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyPowerUpResult, Error>

If supported, PowerUp will power up the wlan chip if it is currently powered down. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered up.

pub fn reset( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyResetResult, Error>

If supported, Reset functionality implements PowerDown then PowerUp in an attempt to recover from an error state. For example, if an interface gets into a bad state or if firmware crashes, the firmware/chip may be unable to perform some actions and Reset may be able to clear the bad state. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered down.

pub fn get_power_state( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyGetPowerStateResult, Error>

Returns the current power state of the wlan chip. After successful initialization of the wlan driver, the state is set to true (power on) by default. power_on set to true indicates that the wlan chip is powered on and false indicates the wlan chip is powered off.

pub fn set_bt_coexistence_mode( &self, payload: &WlanPhySetBtCoexistenceModeRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhySetBtCoexistenceModeResult, Error>

Set the Bluetooth coexistence mode. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: device does not support the specified BT coexistence mode.

pub fn set_tx_power_scenario( &self, payload: &WlanPhySetTxPowerScenarioRequest, ___deadline: MonotonicInstant, ) -> Result<WlanPhySetTxPowerScenarioResult, Error>

pub fn reset_tx_power_scenario( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyResetTxPowerScenarioResult, Error>

pub fn get_tx_power_scenario( &self, ___deadline: MonotonicInstant, ) -> Result<WlanPhyGetTxPowerScenarioResult, Error>